@@ -7,7 +7,7 @@ use crate::{
         sample_encode::cache::ScoringInfo,
     },
     console_ext::style,
-    ffmpeg::{self, FfmpegEncodeArgs},
+    ffmpeg::{self, FfmpegEncodeArgs, remove_arg},
     ffprobe::{self, Ffprobe},
     log::ProgressLogger,
     process::FfmpegOut,
@@ -159,7 +159,11 @@ pub fn run(
         let input_pix_fmt = input_probe.pixel_format();
         let input_is_image = input_probe.is_image;
         let input_len = fs::metadata(&*input).await?.len();
-        let enc_args = args.to_encoder_args(crf, &input_probe)?;
+        let mut enc_args = args.to_ffmpeg_args(crf, &input_probe)?;
+        // ignore user -fps_mode for sample encoding, as we always use passthrough
+        remove_arg(&mut enc_args.output_args, "-fps_mode");
+        remove_arg(&mut enc_args.output_args, "-vsync");
+
         let duration = input_probe.duration.clone()?;
         let input_fps = input_probe.fps.clone()?;
         let samples = sample_args.sample_count(duration).max(1);
@@ -314,7 +318,6 @@ pub fn run(
                                 match vmaf {
                                     VmafOut::Done(score) => {
                                         vmaf_score = Some(score);
-                                        break;
                                     }
                                     VmafOut::Progress(FfmpegOut::Progress { time, fps, .. }) => {
                                         yield Update::Status(Status {
@@ -360,7 +363,8 @@ pub fn run(
                             });
 
                             let lavfi = super::xpsnr::lavfi(
-                                score.reference_vfilter.as_deref().or(args.vfilter.as_deref())
+                                score.reference_vfilter.as_deref().or(args.vfilter.as_deref()),
+                                PixelFormat::opt_max(enc_args.pix_fmt, input_pix_fmt),
                             );
                             let xpsnr_out = xpsnr::run(&sample, &encoded_sample, &lavfi, xpsnr_opts.fps())?;
                             let mut xpsnr_out = pin!(xpsnr_out);
@@ -370,7 +374,6 @@ pub fn run(
                                 match next {
                                     XpsnrOut::Done(s) => {
                                         score = Some(s);
-                                        break;
                                     }
                                     XpsnrOut::Progress(FfmpegOut::Progress { time, fps, .. }) => {
                                         yield Update::Status(Status {
@@ -718,7 +721,7 @@ impl StdoutFormat {
                 let mut json = serde_json::json!({
                     "predicted_encode_size": predicted_encode_size,
                     "predicted_encode_percent": encode_percent,
-                    "predicted_encode_seconds": predicted_encode_time.as_secs(),
+                    "predicted_encode_seconds": predicted_encode_time.as_secs_f64(),
                 });
                 match score_kind {
                     ScoreKind::Vmaf => json["vmaf"] = (*score).into(),
